/* Name: uart.c
 * Project: AVR USB driver for CDC interface on Low-Speed USB
 * Author: Osamu Tamura
 * Creation Date: 2006-06-18
 * Tabsize: 4
 * Copyright: (c) 2006 by Recursion Co., Ltd.
 * License: Proprietary, free under certain conditions. See Documentation.
 *
 * 2006-07-08   adapted to higher baud rate by T.Kitazawa
 */
/*
General Description:
    This module implements the UART rx/tx system of the USB-CDC driver.

Note: This module violates the rule that interrupts must not be disabled for
longer than a couple of instructions (see usbdrv.h). Running UART interrupt
handlers with sei as the first instruction is not possible because it would
recurse immediately (the cause of the interrupt has not been removed). If
we collect the data and then call sei(), we win little. We therefore decide
to violate the rule. The effect on USB operation is, that packages may be
lost. This is equivalent to a package being dropped due to a CRC error. The
host will therefore retry the transfer after a timeout. It is therefore very
likely that no effect is seen at the application layer.
*/

#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>   /* needed by usbdrv.h */
#include "oddebug.h"
#include "uart.h"
#include "usbdrv.h"
#include "cc2500.h"
#include "rgbtohsv.h"



volatile char lights_need_update;
volatile char light_data[9];



/* UART buffer */
uchar    rx_buf[RX_SIZE], tx_buf[TX_SIZE];
uchar    urptr, uwptr, irptr, iwptr;

void uartPoll(void)
{
    char d;

    if (uwptr!=irptr) {
	d    = tx_buf[irptr];
	irptr   = (irptr + 1) & TX_MASK;
    }
    
    usbEnableAllRequests();
//    uartRxBufAppend( data );
}

uchar uartRxIsBusy(void)
{
    return 0;
}


unsigned char buff[9];

#define MAXINTERVAL (16000000/4800/256)*10

void SendByte(char c) {
    static int st=0;
    static unsigned char buff[9];

    //Use tccr1 to check for large delays between bytes, indicating a new packet.
//    if (TCNT1>MAXINTERVAL) st=0;
    TCCR1B=4; //clk/256
    TCNT1=1; 
    
    buff[st]=c;
    st++;

    if (st==9) {
	setrgb(buff);
	st=0;
    }
}


